
/**
 * Adds first and last classes to tabs.
 */
Drupal.behaviors.evoClassTabs = function(context) {
	$('.tabs li:not(.evoClassTabs-processed):first-child').addClass('first');
	$('.tabs li:not(.evoClassTabs-processed):last-child').addClass('last');
};

/**
 * Display panel when hovering.
 */
Drupal.behaviors.evoTogglePanel = function(context) {
	$('#secondary:not(.evoTogglePanel-processed)').addClass('evoTogglePanel-processed').click(function(){ 
		if ($(this).hasClass('collapsed')){
			$(this).removeClass('collapsed').css('height', '26px').animate({
				height: '230px'
			}, 500);	
		}
		else {
			$(this).animate({
				height: '26px'
			}, 500, function(){
				$(this).addClass('collapsed');
			});		
		}
	});
};

/**
 * Display form item descriptions when in focus.
 */
Drupal.behaviors.expandFormItemDescriptions = function(context) {
	var selectors = []
	$.each(['input', 'textarea', 'select'], function(i, element){ 
		selectors.push('.form-item ' + element + ':not(.expandFormItemDescriptions-processed)');
	});
	$(selectors.join(',')).addClass('expandFormItemDescriptions-processed').focus(function(){
		$('.form-item .description.visible').slideUp(400).removeClass('visible');
		$(this).parents('.form-item').children('.description').slideDown(400).addClass('visible');
	});
};

/**
 * Creates tabs from top-level fieldsets for a more intuitive UI. 
 */
Drupal.behaviors.createTabsFromFieldsets = function(context) {
	// Collect top-level fieldsets and hide them initially
	var fieldsets = $('fieldset:not(.createTabsFromFieldsets-processed, fieldset fieldset)')
		.addClass('createTabsFromFieldsets-processed');
	
	// Only one or less fieldsets are available
	if (fieldsets.length <= 1)
		return;
		
	// @todo: add 'to top' image fixed to bottom (use easing function)
	// @todo: solution for panel admin-panel items, to many or to few look dumb
	// @todo: move below title/body for node/add/page etc...
	
	// Build tab markup
	$(fieldsets).hide()
	var total = fieldsets.length;
	var tabs = '<div class="tabs-wrapper"><ul class="tabs">';
	$(fieldsets).each(function(i, fieldset) {
		classes = []
		if (i == 0){ classes.push('first'); classes.push('active') }
		if (i == (total - 1)) { classes.push('last') }
		var title = $('legend', fieldset).html();
		title = title.replace(/\<(?:[^>]+)\>/, '');
		tabs += '<li class="' + classes.join(' ') + '"><a href="#fieldset-tab-' + i + '">' + title + '</a></li>'
		$(fieldset).attr('id', 'fieldset-tab-' + i).addClass('fieldset-tab');
	});
	tabs += '</ul><div class="clear"></div></div><!-- End .tabs-wrapper -->';
	
	// Add generated tab markup
	tabs = $(tabs);
	$('#primary').prepend(tabs);
	$($(fieldsets).get(0)).fadeIn(400);
	$('legend', $(fieldsets).get(0)).remove();
	
	// Toggle tabs
	$('a', tabs).click(function(){
		$('li.active', tabs).removeClass('active');
		$(this).parents('li').addClass('active');
		$(fieldsets).hide(); 
		var fieldsetID = '#' + $(this).attr('href').replace('#', '');
		$(fieldsetID).removeClass('collapsed').fadeIn(400);
		$('legend', fieldsetID).remove();
		return false;
	});
};